/* This file is automatically generated.  DO NOT EDIT!
   Instead, edit gen-table.pl and re-run.  */

#ifndef GCC_CHARTABLES_H
#define GCC_CHARTABLES_H

#define LETTER_START 1
#define LETTER_PART  2

static const char page0[256] = {
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 
  0, 0, 0, (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, (LETTER_PART | LETTER_START), 0, 
  0, 0, 0, 0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START)
};

static const char page2[256] = {
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0
};

static const char page3[256] = {
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page4[256] = {
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0
};

static const char page5[256] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, (LETTER_PART), 0, 
  (LETTER_PART), (LETTER_PART), 0, (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0
};

static const char page6[256] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, (LETTER_PART), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), 0, 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), (LETTER_PART), 
  (LETTER_PART), 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0
};

static const char page7[256] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page9[256] = {
  0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART), 
  (LETTER_PART | LETTER_START), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART), (LETTER_PART), 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART), 0, (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, (LETTER_PART), (LETTER_PART), 0, 0, (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), 0, 
  0, 0, 0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART), (LETTER_PART), 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0
};

static const char page10[256] = {
  0, 0, (LETTER_PART), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART), 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 0, 
  0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART), 
  (LETTER_PART | LETTER_START), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), 0, 0, (LETTER_PART | LETTER_START), 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 0, 0, 0, 
  0, 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page11[256] = {
  0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART), 
  (LETTER_PART | LETTER_START), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, (LETTER_PART), 
  (LETTER_PART), 0, 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 
  0, 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, 0, 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0
};

static const char page12[256] = {
  0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), 
  (LETTER_PART), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 0, 0, 0, 
  0, 0, 0, 0, (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0
};

static const char page13[256] = {
  0, 0, (LETTER_PART), (LETTER_PART), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, (LETTER_PART), 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, (LETTER_PART), 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page14[256] = {
  0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), (LETTER_PART), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), (LETTER_PART), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, (LETTER_PART), (LETTER_PART), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page15[256] = {
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), 0, (LETTER_PART), 0, 
  (LETTER_PART), 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page16[256] = {
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, 0, 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 
  0, 0, 0, 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page17[256] = {
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0
};

static const char page18[256] = {
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START)
};

static const char page19[256] = {
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page20[256] = {
  0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START)
};

static const char page22[256] = {
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0
};

static const char page23[256] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 0, 0, 0, 
  0, (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0
};

static const char page24[256] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 
  0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, 0, 0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0
};

static const char page30[256] = {
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0
};

static const char page31[256] = {
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0
};

static const char page32[256] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page33[256] = {
  0, 0, (LETTER_PART | LETTER_START), 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0
};

static const char page48[256] = {
  0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0
};

static const char page49[256] = {
  0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0
};

static const char page52[256] = {
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page77[256] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START)
};

static const char page78[256] = {
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page159[256] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page164[256] = {
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START)
};

static const char page172[256] = {
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page215[256] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char page250[256] = {
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0
};

static const char page251[256] = {
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART), (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START)
};

static const char page253[256] = {
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0
};

static const char page254[256] = {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, (LETTER_PART)
};

static const char page255[256] = {
  0, 0, 0, 0, (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), (LETTER_PART), 
  0, 0, 0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, (LETTER_PART | LETTER_START), 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 0, 0, 
  (LETTER_PART | LETTER_START), (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, (LETTER_PART | LETTER_START), 
  (LETTER_PART | LETTER_START), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

static const char *const type_table[256] = {
  page0,
  (char *) (LETTER_PART | LETTER_START),
  page2,
  page3,
  page4,
  page5,
  page6,
  page7,
  (char *) 0,
  page9,
  page10,
  page11,
  page12,
  page13,
  page14,
  page15,
  page16,
  page17,
  page18,
  page19,
  page20,
  (char *) (LETTER_PART | LETTER_START),
  page22,
  page23,
  page24,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  page30,
  page31,
  page32,
  page33,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  page48,
  page49,
  (char *) 0,
  (char *) 0,
  page52,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  page77,
  page78,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  page159,
  (char *) (LETTER_PART | LETTER_START),
  (char *) (LETTER_PART | LETTER_START),
  (char *) (LETTER_PART | LETTER_START),
  (char *) (LETTER_PART | LETTER_START),
  page164,
  (char *) (LETTER_PART | LETTER_START),
  (char *) (LETTER_PART | LETTER_START),
  (char *) (LETTER_PART | LETTER_START),
  (char *) (LETTER_PART | LETTER_START),
  (char *) (LETTER_PART | LETTER_START),
  (char *) (LETTER_PART | LETTER_START),
  (char *) (LETTER_PART | LETTER_START),
  page172,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  page215,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) 0,
  (char *) (LETTER_PART | LETTER_START),
  page250,
  page251,
  (char *) (LETTER_PART | LETTER_START),
  page253,
  page254,
  page255
};

#endif /* ! GCC_CHARTABLES_H */
